# atd-utils-email (emailutil)
Python utilities for sending emails with a gmail account.

## Installation
```
pip install atd_emailutil
```

## License

As a work of the City of Austin, this project is in the public domain within the United States.

Additionally, we waive copyright and related rights of the work worldwide through the [CC0 1.0 Universal public domain dedication](https://creativecommons.org/publicdomain/zero/1.0/).
